/**
 * @file
 *
 * Wrapper for time-related stuff.  This is mainly because Mac OS X
 * does not support POSIX real-time functionality.  Here we provide
 * an interface that will support OS functionality as available.
 *
 * @author Jens Teubner <jens.teubner@inf.ethz.ch>
 *
 * (c) 2010 ETH Zurich, Systems Group
 *
 * $Id: time.h 1100 2011-08-17 14:32:58Z jteubner $
 */

#ifndef TIME_H
#define TIME_H

#ifdef HAVE_LIBRT

#include <time.h>

#define nb_gettime(tm) \
    clock_gettime (CLOCK_REALTIME, (tm))

#define nb_nanosleep(ts) \
    clock_nanosleep (CLOCK_REALTIME, TIMER_ABSTIME, (ts), NULL)

#else

#include <sys/time.h>

int nb_gettime (struct timespec *ts);

void nb_nanosleep (struct timespec *ts);

#endif

#endif  /* TIME_H */
