/**
 * @file
 *
 * Generate (allocate) a working set.
 *
 * @author Jens Teubner <jens.teubner@inf.ethz.ch>
 *
 * (c) 2010 ETH Zurich, Systems Group
 *
 * $Id: generate.c 1100 2011-08-17 14:32:58Z jteubner $
 */

#include "config.h"

#include <assert.h>
#include <stdlib.h>
#include <stdio.h>

#include "workset/workset.h"

#include "mem/mem.h"

/**
 * Generate a working set of the given size (in bytes).  @a size must
 * be a multiple of the system's pointer size (i.e., four bytes on 32-bit
 * architectures, eight bytes on 64-bit architectures).
 *
 * @param size size of working set in bytes
 */
elem_t *
#if HAVE_LIBNUMA
generate_workset (size_t size, struct bitmask *nodemask)
#else
generate_workset (size_t size, void *nodemask)
#endif
{
    elem_t *ret;

    if (size % sizeof (elem_t) != 0)
    {
        size = size + (sizeof (elem_t) - (size % sizeof (elem_t)));
        fprintf (stderr, "in generate_workset(): size must be a multiple "
                " of %lu, rounded to %lu\n", sizeof (elem_t), size);
    }

    ret = nb_alloc (size, nodemask);

    if (!ret)
    {
        fprintf (stderr, "Problem in memory allocation (out of memory?).\n");
        exit (EXIT_FAILURE);
    }

    return ret;
}
